PyXMake Developer Guide: PyXMake.VTL.openapi Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.openapi Namespace Reference

## Functions
| main (BuildID, source="https://stmlab.fa-services.intra.dlr.de/2/openapi.json", output=None, **kwargs)

## Variables
| parser = argparse.ArgumentParser(description='CLI wrapper options for OpenAPI client generator.')
| type
| str
| nargs
| help
| GetBoolean
| const
| True
| default
str | delimn = "."
| _ = sys.argv[1]
| args
| project = args.name[0]
| source = args.source[0] ;
| version
| output
| build
| filename

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Create a Python package from an OpenAPI specification. Optionally, create a
    portable installer instead.

    Created on 21.10.2022

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.openapi.main | ( |  | BuildID,
|  |  | source = "https://stmlab.fa-services.intra.dlr.de/2/openapi.json",
|  |  | output = None,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 48 of file openapi.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.openapi._ = sys.argv[1]
| protected

Definition at line 131 of file openapi.py.

## ◆ args

PyXMake.VTL.openapi.args

Definition at line 132 of file openapi.py.

## ◆ build

PyXMake.VTL.openapi.build

Definition at line 144 of file openapi.py.

## ◆ const

PyXMake.VTL.openapi.const

Definition at line 123 of file openapi.py.

## ◆ default

PyXMake.VTL.openapi.default

Definition at line 123 of file openapi.py.

## ◆ delimn

str PyXMake.VTL.openapi.delimn = "."

Definition at line 127 of file openapi.py.

## ◆ filename

PyXMake.VTL.openapi.filename

Definition at line 147 of file openapi.py.

## ◆ GetBoolean

PyXMake.VTL.openapi.GetBoolean

Definition at line 123 of file openapi.py.

## ◆ help

PyXMake.VTL.openapi.help

Definition at line 118 of file openapi.py.

## ◆ nargs

PyXMake.VTL.openapi.nargs

Definition at line 118 of file openapi.py.

## ◆ output

PyXMake.VTL.openapi.output

Definition at line 141 of file openapi.py.

## ◆ parser

PyXMake.VTL.openapi.parser = argparse.ArgumentParser(description='CLI wrapper options for OpenAPI client generator.')

Definition at line 117 of file openapi.py.

## ◆ project

PyXMake.VTL.openapi.project = args.name[0]

Definition at line 134 of file openapi.py.

## ◆ source

PyXMake.VTL.openapi.source = args.source[0] ;

Definition at line 136 of file openapi.py.

## ◆ str

PyXMake.VTL.openapi.str

Definition at line 118 of file openapi.py.

## ◆ True

PyXMake.VTL.openapi.True

Definition at line 123 of file openapi.py.

## ◆ type

PyXMake.VTL.openapi.type

Definition at line 118 of file openapi.py.

## ◆ version

PyXMake.VTL.openapi.version

Definition at line 138 of file openapi.py.